# igym

This is the official repository for the `inno-gym` package.

A great gym for benchmark agent innovation.

PLACEHOLDER.

## Installation

```bash
pip install inno-gym
```

## Usage
```python
import igym

igym.hello()
```